@@ -340,6 +340,40 @@ class Accountant:
         log.info(operation)
         return operation
 
+    def trade_all_or_none(self, from_currency: str, to_currency: str, from_amount: str, to_amount: str, memo: str, metadata: dict = {}):
+       # operation in metadata would be trade now, {**metadata, operation: 'TRADE'}
+       # memo = memo + '_TRADE'
+       # from_currency -> user's mainbook to cs cashbook
+       # to_currency -> cs cashbook to user's mainbook
+        entries = [
+            # debit user from_amount
+            {
+                "bookId": self.bank_account['ledger_books']['main_balance']['id'],
+                "assetId": from_currency,
+                "value":  str(Decimal(from_amount) * Decimal("-1"))
+            },
+            # credit to cs cashbook from_amount
+            {
+                "bookId": self.DEFAULT_CASH_BOOK_ID['id'],
+                "assetId": from_currency,
+                "value": str(from_amount)
+            }, 
+            # to_currency flow
+            {
+                "bookId": self.DEFAULT_CASH_BOOK_ID['id'],
+                "assetId": to_currency,
+                "value": str(Decimal(to_amount) * Decimal("-1"))
+            },
+            {
+                "bookId": self.bank_account['ledger_books']['main_balance']['id'],
+                "assetId": to_currency,
+                "value": str(to_amount)
+            }
+        ]
+        operation = self.ledger.post_operation(OperationType.CUSTOM, entries, memo= memo + "_TRADE", metadata={**metadata, **{"operation": "TRADE"}})
+        log.info(operation)
+        return operation
+
     def get_order_fill_status_in_bulk(self, order_id_list: list):
         log.info("---------get_Limit_order_fill_status_in_bulk----------")
         bulk_order_fill_status = []
