@@ -113,6 +113,9 @@ class LedgerClient:
     def get_operation(self, operation_id: str):
         return self._execute("getOperation", operation_id, read_only_method=True)
 
+    def get_operation_by_memo(self, memo: str):
+        return self._execute("getOperationByMemo", memo, read_only_method=True)
+
     def get_operations(self, book_id: str, metadata_filter: dict = None):
         return self._execute("getOperations", book_id, metadata_filter, read_only_method=True)
 
